@@ -7,12 +7,12 @@ _netid_to_name = {
 
 _contract_addresses_proxy_v1 = {
     "mumbai": {
-        "StableToken": "0x2E4c42aB89E8f928C74571Bb54C2DaA28605937B",
-        "Manager": "0xc7Bf6E9a1EE40EB452712F219Ffd57D0feE0691c",
-        "Amm_eth-usdc": "0x9fFeBA1A8cD88D0BDb996Cf75A993fdAfEE8f4f6",
-        "Amm_btc-usdc": "0xec8c5521c4Df81be57436a5DC9e2Ac4C888E0054",
-        "Amm_matic-usdc": "0x74456feE1Cf361787EA0545B7f075A72084a3965",
-        "AmmReader": "0x314426488153C2867Dbb1FC1dee3B406F9E3c7B0"
+        "StableToken": "0x2217d4d1f6FA53B889690ac6A36BD0396f712568",
+        "Manager": "0x5320976b29aD12Cc82B4c1627e0b826Cc4d7f73f",
+        "Amm_eth-usdc": "0x2B0eC54996b745DBb971601B1e18dE648191f3E4",
+        "Amm_btc-usdc": "0x95e1635Abc9800bE39932D3Add71Dd16C33b2d2B",
+        "Amm_matic-usdc": "0x0A0fd7322BE113b9E49062020AB28Aad0a519Cb2",
+        "AmmReader": "0x057DE5538083939304B92eE89c7816A003845D49"
     },
     "local": {
         "StableToken": "0x5FbDB2315678afecb367f032d93F642f64180aa3",
