@@ -494,7 +494,7 @@ class Polysynth:
 
         func = token.approve(*func_params)
         tx_params = self._get_tx_params()
-        txid = self._build_and_send_tx(func, tx_params)
+        receipt = self._build_and_send_tx(func, tx_params)
         tx = None
         try:
             tx = self.w3.eth.wait_for_transaction_receipt(receipt, timeout=self.tx_timeout)
@@ -864,6 +864,36 @@ class Polysynth:
         except PolysynthException as e:
             return e.__dict__()
 
+    def max_base_asset_limit(
+        self,
+        amm: str = None,
+        *args,
+        **kwargs
+        ) -> Response:
+        '''
+            For a market, get trade limit ratio
+
+        Args:
+            amm (str): name of the market, eg; ETH
+
+        Returns:
+            Any: trade limit ratio
+        '''
+        try:
+            if amm is None:
+                raise MissingInputError(StatusCode.BAD_REQUEST.value, StatusCode.MISSING_REQUIRED_ARGS.value, ErrorMessage.MISSING_REQUIRED_ARGS.value%"symbol")
+            amm_contract_addr = _amm_name_to_addr(amm, self.network)
+            amm_contract = _load_contract(
+                    self.w3,
+                    self.network,
+                    abi_name="Amm_" + amm.split("-")[0].upper(),
+                    address=_str_to_addr(amm_contract_addr),
+                )
+            mbl = amm_contract.functions.getMaxBaseAssetLimit().call()
+            return Response(StatusCode.OK.value, None, None, data= {"max_base_asset_limit": round(mbl/10**18, 7)}).__dict__()
+        except PolysynthException as e:
+            return e.__dict__()
+
     def cancel_transaction(self, tx_hash: Optional[str]=None) -> Any:
         try:
             if tx_hash:
@@ -1080,62 +1110,6 @@ class Polysynth:
         
         unrealized_pnl = position[1]
         return unrealized_pnl
-
-    def _get_data_for_jayant(self, amm: str, trader: str, id='latest') -> Any:
-        if amm is None:
-            raise MissingInputError(StatusCode.BAD_REQUEST.value, StatusCode.MISSING_REQUIRED_ARGS.value, ErrorMessage.MISSING_REQUIRED_ARGS.value%"symbol")
-
-        position = self._get_trader_position(amm, trader, id=id)
-
-        _size = _normalize(position[0])
-        _collateral = _normalize(position[1]) # 1
-
-        if position[1] == 0 or position[0] == 0:
-            _leverage = 0
-            _avg_entry_price = 0
-        else:
-            _leverage = '{:.20f}'.format((position[2]/position[1]))
-            _avg_entry_price = '{:.20f}'.format((position[2]/position[0])) #3
-
-        _position_with_funding_payment = self._get_trader_position_with_funding_payment(amm, trader,id=id)
-
-        _collateral_with_funding_rate = _normalize(_position_with_funding_payment[1])
-        _funding_rate_long = _normalize(_position_with_funding_payment[4])
-        _funding_rate_short = _normalize(_position_with_funding_payment[5])
-
-        _with_spot = self._get_position_notional_and_unrealized_pnl(amm, trader, id=id, option=0)
-        _with_twap = self._get_position_notional_and_unrealized_pnl(amm, trader, id=id, option=1)
-
-        _position_notional_spot = _normalize(_with_spot[0])
-        _position_notional_twap = _normalize(_with_twap[0]) #4
-
-        _unrealized_pnl_spot = _normalize(_with_spot[1])
-        _unrealized_pnl_twap = _normalize(_with_twap[1])
-
-        _margin = _normalize(_position_with_funding_payment[1] + _with_spot[1]) #2
-
-        _spot_price = _normalize(self._get_spot_price(amm, id=id))
-
-        _collateral_ratio =  _normalize(self._get_collateral_ratio(amm, trader, id=id))
-
-        return {
-            "amm": amm,
-            "trader": trader,
-            "collateral": _collateral,
-            "size": _size,
-            "leverage": _leverage,
-            "entry_price": _avg_entry_price,
-            "collateral_with_funding_rate": _collateral_with_funding_rate,
-            "funding_rate_long": _funding_rate_long,
-            "funding_rate_short": _funding_rate_short,
-            "position_notional_spot": _position_notional_spot,
-            "position_notional_twap": _position_notional_twap,
-            "unrealized_pnl_spot": _unrealized_pnl_spot,
-            "unrealized_pnl_twap": _unrealized_pnl_twap,
-            "margin": _margin,
-            "spot_price": _spot_price,
-            "collateral_ratio": _collateral_ratio
-        }
     
     def _get_spot_price(self, amm: str, id='latest', **kwargs) -> Any:
         if amm is None:
@@ -1320,8 +1294,8 @@ class Polysynth:
             "to": "0x0000000000000000000000000000000000000000",
             "value": "0x0",
             "gas": gas,
-            "maxFeePerGas": Web3.toWei(gasFee['maxFee'], 'gwei'),
-            'maxPriorityFeePerGas': Web3.toWei(gasFee['maxPriorityFee'], 'gwei'),
+            "maxFeePerGas": Web3.toWei(gasFee['maxFee']*1.1, 'gwei'),
+            'maxPriorityFeePerGas': Web3.toWei(gasFee['maxPriorityFee']*1.1, 'gwei'),
             "nonce": max(
                 self.last_nonce, self.w3.eth.get_transaction_count(self.address)
             ),
@@ -1334,8 +1308,8 @@ class Polysynth:
         return {
             "from": _addr_to_str(self.address),
             "value": value,
-            "maxFeePerGas": Web3.toWei(gasFee['maxFee'], 'gwei'),
-            'maxPriorityFeePerGas': Web3.toWei(gasFee['maxPriorityFee'], 'gwei'),
+            "maxFeePerGas": Web3.toWei(gasFee['maxFee']*1.1, 'gwei'),
+            'maxPriorityFeePerGas': Web3.toWei(gasFee['maxPriorityFee']*1.1, 'gwei'),
             "nonce": nonce,
             "chainId": int(self.w3.net.version),
         }
\ No newline at end of file
